@@ -16,44 +16,45 @@
 __author__ = "Vasyl Khomenko"
 __copyright__ = "Copyright 2013, Qubell.com"
 __license__ = "Apache"
-__version__ = "1.0.10"
+__version__ = "1.0.12"
 __email__ = "vkhomenko@qubell.com"
 
 import logging as log
-
 import requests
 
-from qubell.api.private import application, exceptions
+from qubell.api.private import exceptions
 
 
-class Revision(application.Application):
+class Revision(object):
     """
     Base class for revision
     """
 
-    def __init__(self, context, id):
+    def __init__(self, auth, application, id):
         self.revisionId = id
-        self.context = context
+        self.application = application
+        self.auth = auth
+        my = self.json()
+        self.name = my['name']
 
     def __getattr__(self, key):
         resp = self.json()
-        if not resp.has_key(key):
-            raise exceptions.NotFoundError('Cannot get property %s' % key)
-        return resp[key] or False
+        if resp.has_key(key):
+            return resp[key] or False
+        raise exceptions.NotFoundError('Cannot get revision property %s' % key)
 
     def json(self):
-        url = self.context.api+'/organizations/'+self.context.organizationId+'/applications/'+self.context.applicationId+'/revisions/'+self.revisionId+'.json'
-        resp = requests.get(url, cookies=self.context.cookies, verify=False)
+        url = self.auth.api+'/organizations/'+self.application.organizationId+'/applications/'+self.application.applicationId+'/revisions/'+self.revisionId+'.json'
+        resp = requests.get(url, cookies=self.auth.cookies, verify=False)
         log.debug(resp.text)
         if resp.status_code == 200:
-            resp.json()
-        raise exceptions.ApiError('Unable to get service properties, got error: %s' % resp.text)
+            return resp.json()
+        raise exceptions.ApiError('Unable to get revision properties, got error: %s' % resp.text)
 
     def delete(self):
-        url = self.context.api+'/organizations/'+self.context.organizationId+'/applications/'+self.context.applicationId+'/revisions/'+self.revisionId+'.json'
-        resp = requests.delete(url, cookies=self.context.cookies, verify=False)
+        url = self.auth.api+'/organizations/'+self.application.organizationId+'/applications/'+self.application.applicationId+'/revisions/'+self.revisionId+'.json'
+        resp = requests.delete(url, cookies=self.auth.cookies, verify=False)
         log.debug(resp.text)
-        self.rawRespose = resp
-        if resp.status_code==200:
+        if resp.status_code == 200:
             return True
         raise exceptions.ApiError('Unable to delete revision, got error: %s' % resp.text)
