@@ -16,7 +16,7 @@
 __author__ = "Vasyl Khomenko"
 __copyright__ = "Copyright 2013, Qubell.com"
 __license__ = "Apache"
-__version__ = "1.0.10"
+__version__ = "1.0.12"
 __email__ = "vkhomenko@qubell.com"
 
 import logging as log
@@ -32,8 +32,8 @@ class Environment(Organization):
 
     def __init__(self, context, id):
         self.environmentId = id
-        self.context = context
-        self.context.environmentId = self.environmentId
+        self.auth = context
+        self.auth.environmentId = self.environmentId
         my = self.json()
         self.name = my['name']
 
@@ -44,8 +44,8 @@ class Environment(Organization):
         return resp[key] or False
 
     def json(self):
-        url = self.context.api+'/api/1/organizations/'+self.context.organizationId+'/environments'
-        resp = requests.get(url, auth=(self.context.user, self.context.password), verify=False)
+        url = self.auth.api+'/api/1/organizations/'+self.auth.organizationId+'/environments'
+        resp = requests.get(url, auth=(self.auth.user, self.auth.password), verify=False)
         log.debug(resp.text)
         if resp.status_code == 200:
             env = [x for x in resp.json() if x['id'] == self.environmentId]
@@ -56,17 +56,17 @@ class Environment(Organization):
 
 
     def delete(self):
-        url = self.context.api+'/organizations/'+self.context.organizationId+'/environments/'+self.environmentId+'.json'
+        url = self.auth.api+'/organizations/'+self.auth.organizationId+'/environments/'+self.environmentId+'.json'
         headers = {'Content-Type': 'application/json'}
-        resp = requests.delete(url, cookies=self.context.cookies, data=json.dumps({}), verify=False, headers=headers)
+        resp = requests.delete(url, cookies=self.auth.cookies, data=json.dumps({}), verify=False, headers=headers)
         log.debug(resp.text)
         if resp.status_code == 200:
             return True
         raise exceptions.ApiError('Unable to delete environment %s, got error: %s' % (self.environmentId, resp.text))
 
     def servicesAvailable(self):
-        url = self.context.api+'/organizations/'+self.context.organizationId+'/environments/'+self.environmentId+'/availableServices.json'
-        resp = requests.get(url, cookies=self.context.cookies, verify=False)
+        url = self.auth.api+'/organizations/'+self.auth.organizationId+'/environments/'+self.environmentId+'/availableServices.json'
+        resp = requests.get(url, cookies=self.auth.cookies, verify=False)
         log.debug(resp.text)
         self.rawRespose = resp
         if resp.status_code == 200:
@@ -79,10 +79,10 @@ class Environment(Organization):
         data['serviceIds'].append(service.serviceId)
         data['services'].append(service.json())
 
-        url = self.context.api+'/organizations/'+self.context.organizationId+'/environments/'+self.environmentId+'.json'
+        url = self.auth.api+'/organizations/'+self.auth.organizationId+'/environments/'+self.environmentId+'.json'
         payload = json.dumps(data)
         headers = {'Content-Type': 'application/json'}
-        resp = requests.put(url, cookies=self.context.cookies, data=payload, verify=False, headers=headers)
+        resp = requests.put(url, cookies=self.auth.cookies, data=payload, verify=False, headers=headers)
         log.debug(resp.text)
         self.rawRespose = resp
         if resp.status_code == 200:
@@ -95,10 +95,10 @@ class Environment(Organization):
         data['serviceIds'].remove(service.serviceId)
         data['services'].remove(service.json())
 
-        url = self.context.api+'/organizations/'+self.context.organizationId+'/environments/'+self.environmentId+'.json'
+        url = self.auth.api+'/organizations/'+self.auth.organizationId+'/environments/'+self.environmentId+'.json'
         payload = json.dumps(data)
         headers = {'Content-Type': 'application/json'}
-        resp = requests.put(url, cookies=self.context.cookies, data=payload, verify=False, headers=headers)
+        resp = requests.put(url, cookies=self.auth.cookies, data=payload, verify=False, headers=headers)
         log.debug(resp.text)
         self.rawRespose = resp
         if resp.status_code == 200:
@@ -109,10 +109,10 @@ class Environment(Organization):
         data = self.json()
         data['markers'].append({'name': marker})
 
-        url = self.context.api+'/organizations/'+self.context.organizationId+'/environments/'+self.environmentId+'.json'
+        url = self.auth.api+'/organizations/'+self.auth.organizationId+'/environments/'+self.environmentId+'.json'
         payload = json.dumps(data)
         headers = {'Content-Type': 'application/json'}
-        resp = requests.put(url, cookies=self.context.cookies, data=payload, verify=False, headers=headers)
+        resp = requests.put(url, cookies=self.auth.cookies, data=payload, verify=False, headers=headers)
         log.debug(resp.text)
         self.rawRespose = resp
         if resp.status_code == 200:
@@ -124,10 +124,10 @@ class Environment(Organization):
         data = self.json()
         data['markers'].remove({'name': marker})
 
-        url = self.context.api+'/organizations/'+self.context.organizationId+'/environments/'+self.environmentId+'.json'
+        url = self.auth.api+'/organizations/'+self.auth.organizationId+'/environments/'+self.environmentId+'.json'
         payload = json.dumps(data)
         headers = {'Content-Type': 'application/json'}
-        resp = requests.put(url, cookies=self.context.cookies, data=payload, verify=False, headers=headers)
+        resp = requests.put(url, cookies=self.auth.cookies, data=payload, verify=False, headers=headers)
         log.debug(resp.text)
         self.rawRespose = resp
         if resp.status_code == 200:
@@ -140,10 +140,10 @@ class Environment(Organization):
         data = self.json()
         data['properties'].append({'name': name, 'type': type, 'value': value})
 
-        url = self.context.api+'/organizations/'+self.context.organizationId+'/environments/'+self.environmentId+'.json'
+        url = self.auth.api+'/organizations/'+self.auth.organizationId+'/environments/'+self.environmentId+'.json'
         payload = json.dumps(data)
         headers = {'Content-Type': 'application/json'}
-        resp = requests.put(url, cookies=self.context.cookies, data=payload, verify=False, headers=headers)
+        resp = requests.put(url, cookies=self.auth.cookies, data=payload, verify=False, headers=headers)
         log.debug(resp.text)
         self.rawRespose = resp
         if resp.status_code == 200:
@@ -158,10 +158,10 @@ class Environment(Organization):
             log.error('Unable to remove property %s. Not found.' % name)
         data['properties'].remove(property[0])
 
-        url = self.context.api+'/organizations/'+self.context.organizationId+'/environments/'+self.environmentId+'.json'
+        url = self.auth.api+'/organizations/'+self.auth.organizationId+'/environments/'+self.environmentId+'.json'
         payload = json.dumps(data)
         headers = {'Content-Type': 'application/json'}
-        resp = requests.put(url, cookies=self.context.cookies, data=payload, verify=False, headers=headers)
+        resp = requests.put(url, cookies=self.auth.cookies, data=payload, verify=False, headers=headers)
         log.debug(resp.text)
         self.rawRespose = resp
         if resp.status_code == 200:
@@ -175,10 +175,10 @@ class Environment(Organization):
         data['serviceIds'] = []
         data['services'] = []
 
-        url = self.context.api+'/organizations/'+self.context.organizationId+'/environments/'+self.environmentId+'.json'
+        url = self.auth.api+'/organizations/'+self.auth.organizationId+'/environments/'+self.environmentId+'.json'
         payload = json.dumps(data)
         headers = {'Content-Type': 'application/json'}
-        resp = requests.put(url, cookies=self.context.cookies, data=payload, verify=False, headers=headers)
+        resp = requests.put(url, cookies=self.auth.cookies, data=payload, verify=False, headers=headers)
         log.debug(resp.text)
         self.rawRespose = resp
         if resp.status_code == 200:
@@ -193,10 +193,10 @@ class Environment(Organization):
         data = self.json()
         data['policies'].append(new)
 
-        url = self.context.api+'/organizations/'+self.context.organizationId+'/environments/'+self.environmentId+'.json'
+        url = self.auth.api+'/organizations/'+self.auth.organizationId+'/environments/'+self.environmentId+'.json'
         payload = json.dumps(data)
         headers = {'Content-Type': 'application/json'}
-        resp = requests.put(url, cookies=self.context.cookies, data=payload, verify=False, headers=headers)
+        resp = requests.put(url, cookies=self.auth.cookies, data=payload, verify=False, headers=headers)
         log.debug(resp.text)
         self.rawRespose = resp
         if resp.status_code == 200:
@@ -208,10 +208,10 @@ class Environment(Organization):
         data = self.json()
         data.update({'providerId': provider.providerId})
 
-        url = self.context.api+'/organizations/'+self.context.organizationId+'/environments/'+self.environmentId+'.json'
+        url = self.auth.api+'/organizations/'+self.auth.organizationId+'/environments/'+self.environmentId+'.json'
         payload = json.dumps(data)
         headers = {'Content-Type': 'application/json'}
-        resp = requests.put(url, cookies=self.context.cookies, data=payload, verify=False, headers=headers)
+        resp = requests.put(url, cookies=self.auth.cookies, data=payload, verify=False, headers=headers)
         log.debug(resp.text)
         self.rawRespose = resp
         if resp.status_code == 200:
@@ -221,10 +221,10 @@ class Environment(Organization):
     def set_backend(self, zone):
         data = self.json()
         data.update({'backend': zone})
-        url = self.context.api+'/organizations/'+self.context.organizationId+'/environments/'+self.environmentId+'.json'
+        url = self.auth.api+'/organizations/'+self.auth.organizationId+'/environments/'+self.environmentId+'.json'
         payload = json.dumps(data)
         headers = {'Content-Type': 'application/json'}
-        resp = requests.put(url, cookies=self.context.cookies, data=payload, verify=False, headers=headers)
+        resp = requests.put(url, cookies=self.auth.cookies, data=payload, verify=False, headers=headers)
         log.debug(resp.text)
         if resp.status_code == 200:
             return resp.json()
