@@ -16,7 +16,7 @@
 __author__ = "Vasyl Khomenko"
 __copyright__ = "Copyright 2013, Qubell.com"
 __license__ = "Apache"
-__version__ = "1.0.10"
+__version__ = "1.0.12"
 __email__ = "vkhomenko@qubell.com"
 
 import logging as log
@@ -41,15 +41,15 @@ class Instance(application.Application):
 
     def __init__(self, context, id=None):
         self.instanceId = id
-        self.context = context
-        self.context.instanceId = self.instanceId
+        self.auth = context
+        self.auth.instanceId = self.instanceId
         self.name = self.name
         self._status = 'Init'
 
     def json(self):
 
-        url = self.context.api+'/api/1/instances/'+self.instanceId
-        resp = requests.get(url, auth=(self.context.user, self.context.password), verify=False)
+        url = self.auth.api+'/api/1/instances/'+self.instanceId
+        resp = requests.get(url, auth=(self.auth.user, self.auth.password), verify=False)
         log.debug(resp.text)
         if resp.status_code == 200:
             return resp.json()
@@ -102,10 +102,10 @@ class Instance(application.Application):
 
     def runWorkflow(self, name, parameters={}):
         log.info("Running workflow %s" % name)
-        url = self.context.api+'/api/1/instances/'+self.instanceId+'/'+name
+        url = self.auth.api+'/api/1/instances/'+self.instanceId+'/'+name
         headers = {'Content-Type': 'application/json'}
         payload = json.dumps(parameters)
-        resp = requests.post(url, auth=(self.context.user, self.context.password), data=payload, verify=False, headers=headers)
+        resp = requests.post(url, auth=(self.auth.user, self.auth.password), data=payload, verify=False, headers=headers)
         log.debug(resp.text)
         if resp.status_code == 200:
             return resp.json()
