@@ -16,7 +16,7 @@
 __author__ = "Vasyl Khomenko"
 __copyright__ = "Copyright 2013, Qubell.com"
 __license__ = "Apache"
-__version__ = "1.0.10"
+__version__ = "1.0.12"
 __email__ = "vkhomenko@qubell.com"
 
 import logging as log
@@ -31,7 +31,7 @@ from qubell.api.private import exceptions
 class Provider(Organization):
 
     def __init__(self, context, id):
-        self.context = context
+        self.auth = context
         self.providerId = id
         my = self.json()
         self.__dict__.update(my)
@@ -43,8 +43,8 @@ class Provider(Organization):
         return resp[key] or False
 
     def json(self):
-        url = self.context.api+'/organizations/'+self.context.organizationId+'/providers.json'
-        resp = requests.get(url, cookies=self.context.cookies, verify=False)
+        url = self.auth.api+'/organizations/'+self.auth.organizationId+'/providers.json'
+        resp = requests.get(url, cookies=self.auth.cookies, verify=False)
         log.debug(resp.text)
         if resp.status_code == 200:
             provider = [x for x in resp.json() if x['id'] == self.providerId]
@@ -53,9 +53,9 @@ class Provider(Organization):
         raise exceptions.ApiError('Unable to get provider %s properties, got error: %s' % (self.providerId, resp.text))
 
     def delete(self):
-        url = self.context.api+'/organizations/'+self.context.organizationId+'/providers/'+self.providerId+'.json'
+        url = self.auth.api+'/organizations/'+self.auth.organizationId+'/providers/'+self.providerId+'.json'
         headers = {'Content-Type': 'application/json'}
-        resp = requests.delete(url, cookies=self.context.cookies, data=json.dumps({}), verify=False, headers=headers)
+        resp = requests.delete(url, cookies=self.auth.cookies, data=json.dumps({}), verify=False, headers=headers)
         log.debug(resp.text)
         if resp.status_code == 200:
             return True
